
RELEASE_VERSION='0.2.548318040'
BUILD_DATE='Thu May 26 06:21:20 UTC 2022'
BUILD_MACHINE_INFO='Linux runner-opyxurxq-project-28359933-concurrent-0mbspt 5.4.181-99.354.amzn2.x86_64 #1 SMP Wed Mar 2 18:50:46 UTC 2022 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='2507470932'
GIT_COMMIT_SHA='de1d741015ef539dde501ccf6240d3bccccaeacd'
GIT_BRANCH='main'
